@@ -7,15 +7,20 @@
 #include "zeek/IPAddr.h"
 #include "zeek/PrefixTable.h"
 
-ZEEK_FORWARD_DECLARE_NAMESPACED(IP_Hdr, zeek);
-ZEEK_FORWARD_DECLARE_NAMESPACED(Val, zeek);
+namespace zeek
+	{
 
-namespace zeek::detail {
+class IP_Hdr;
+class Val;
 
-class PacketFilter {
+namespace detail
+	{
+
+class PacketFilter
+	{
 public:
 	explicit PacketFilter(bool arg_default);
-	~PacketFilter()	{}
+	~PacketFilter() { }
 
 	// Drops all packets from a particular source (which may be given
 	// as an AddrVal or a SubnetVal) which hasn't any of TCP flags set
@@ -33,13 +38,14 @@ public:
 	bool RemoveDst(Val* dst);
 
 	// Returns true if packet matches a drop filter
-	bool Match(const std::unique_ptr<IP_Hdr>& ip, int len, int caplen);
+	bool Match(const std::shared_ptr<IP_Hdr>& ip, int len, int caplen);
 
 private:
-	struct Filter {
+	struct Filter
+		{
 		uint32_t tcp_flags;
 		double probability;
-	};
+		};
 
 	static void DeleteFilter(void* data);
 
@@ -48,8 +54,7 @@ private:
 	bool default_match;
 	PrefixTable src_filter;
 	PrefixTable dst_filter;
-};
+	};
 
-} // namespace zeek::detail
-
-using PacketFilter [[deprecated("Remove in v4.1. Use zeek::detail::PacketFilter.")]] = zeek::detail::PacketFilter;
+	} // namespace detail
+	} // namespace zeek
