@@ -99,7 +99,7 @@ public:
 	 * @param is_live True if \a path represents a live interface, false
 	 * for a file.
 	 *
-	 * @return The new packet source, or null if an error occured.
+	 * @return The new packet source, or null if an error occurred.
 	 */
 	PktSrc* OpenPktSrc(const std::string& path, bool is_live);
 
@@ -144,7 +144,7 @@ public:
 	 * is called during RegisterFd and UnregisterFd since those methods cause
 	 * changes to the active set of file descriptors.
 	 */
-	void Wakeup(const std::string& where);
+	void Wakeup(std::string_view where);
 
 private:
 	/**
@@ -186,7 +186,7 @@ private:
 		 * @param where a string denoting where this ping was called from. Used
 		 * for debugging output.
 		 */
-		void Ping(const std::string& where);
+		void Ping(std::string_view where);
 
 		// IOSource API methods
 		void Process() override;
@@ -216,7 +216,7 @@ private:
 	int zero_timeout_count = 0;
 	WakeupHandler* wakeup = nullptr;
 	int poll_counter = 0;
-	int poll_interval = 100;
+	int poll_interval = 0; // Set in InitPostScript() based on const value.
 
 	int event_queue = -1;
 	std::map<int, IOSource*> fd_map;
